<?php
/*
Plugin Name: Booking Package WP
Plugin URI:  https://saasproject.net/plans/
Description: Booking Package WP is a high-performance booking system that anyone can easily use.
Version:     1.1.3
Author:      SAASPROJECT
Author URI:  https://saasproject.net/
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: booking-package
Domain Path: /languages
*/
	
	if(!defined('ABSPATH')){
    	exit;
	}
	
	define("BOOKING_PACKAGE_EXTENSION_URL", "https://saasproject.net/api/1.0/");
	
	define("BOOKING_PACKAGE_STRIPE_PUBLIC_KEY", "pk_live_6o6UUlTOZInuOGEQPPjkfuyU");
	
	class Booking_app {
		
		public $db_version = "0.0.2";
		
		public $table_name = null;
		
		public $plugin_name = "booking-package";
		
		public $prefix = 'booking_package_';
		
		public $action_control = "booking_app_action";
		
		public $action_public = "booking_app_public_action";
		
		public $locale = "en";
		
		public $igo = null;
		
		public $calendarAccountType = 0;
		
		public function __construct() {
			
			global $wpdb;
			#$this->table_name = $wpdb->prefix.'booking_package';
			#$this->action = "booking_app_action";
			
			if(function_exists('register_activation_hook')){
				
				register_activation_hook(__FILE__, array($this,'create_database'));
				
			}
			
			if(function_exists('register_deactivation_hook')){
				
				#register_deactivation_hook(__FILE__, array($this,'deactivation'));
				register_deactivation_hook(__FILE__, array($this, 'deactivation_event'));
				
			}
			
			
			
			$pluginName = $this->plugin_name;
			$test = load_plugin_textdomain($pluginName, false, dirname( plugin_basename( __FILE__ ) ).'/languages');
			
			add_action('admin_menu', array($this, 'add_pages'));
			add_action('admin_bar_menu', array($this, 'admin_bar_menu'), 100);
			add_action('wp_ajax_'.$this->action_control, array($this, 'wp_ajax_booking_package'));
			add_action('wp_ajax_nopriv_'.$this->action_control, array($this, 'wp_ajax_booking_package'));
			
			add_action('wp_ajax_'.$this->action_public, array($this, 'wp_ajax_booking_package_for_public'));
			add_action('wp_ajax_nopriv_'.$this->action_public, array($this, 'wp_ajax_booking_package_for_public'));
			
			add_shortcode('booking_app', array($this, 'display_booking_page'));
			add_shortcode('booking_package', array($this, 'display_booking_page'));
			
			add_filter( 'locale', array($this, 'plugin_localized'));
			add_filter('cron_schedules', array($this, 'cron_interval'));
			add_action('retry_to_send_to_server', array($this, 'retry_to_send_to_server'));
			if(!wp_next_scheduled('retry_to_send_to_server')){
				
				wp_schedule_event(time(), 'retry_to_send_to_server_thirty_minutes', 'retry_to_send_to_server');
				
			}
			
			add_action('admin_head', array($this, 'screen_meta'));
			
			
			
			if(isset($_GET['ical'])){
				
				add_action('init', array($this, 'ical_feeds'));
				
			}
			
			if(isset($_GET['webhook']) || isset($_POST['webhook'])){
				
				add_action('init', array($this, 'webhook'));
				
			}
			
			if(isset($_POST['api'])){
				
				add_action('init', array($this, 'api'));
				
			}
			
		}
		
		public function plugin_localized($locale){
			
			#var_dump($locale);
			if(isset($_POST['locale'])){
				
				$this->locale = sanitize_key($_POST['locale']);
				return sanitize_key($_POST['locale']);
				
			}
			
			$this->locale = $locale;
			return $locale;
			
		}
		
		public function create_database(){
			
			require_once(get_home_path() . 'wp-admin/includes/upgrade.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Database.php');
			
			$database = new Database($this->prefix, $this->db_version);
			$database->create();
			
			$setting = new setting($this->prefix, $this->plugin_name);
			$setting->activation(BOOKING_PACKAGE_EXTENSION_URL, "activation");
			
			$this->createFirstCalendar();
			
			#$this->activation("activation");
			
		}
		
		public function update_database(){
			
			$installed_ver = get_option($this->prefix."db_version");
			if($installed_ver != $this->db_version){
				$this->create_database();
				update_option($this->prefix."db_version", $this->db_version);
				
			}
			
		}
		
		public function display_booking_page($atts){
			
			$atts = extract(shortcode_atts(array('id' => 1), $atts));
			#var_dump($atts);
			$accountKey = $id;
			#print "accountKey = ".$accountKey."<br>\n";
			
			
			$timezone = get_option('timezone_string');
            date_default_timezone_set($timezone);
            
            require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
            require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
            
            $setting = new setting($this->prefix, $this->plugin_name);
			$list = $setting->getList();
			$courseList = $setting->getCourseList($accountKey);
			$formData = $setting->getForm($accountKey);
			
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$schedule->deleteOldDaysInSchedules();
			$schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
			$calendarAccount = $schedule->getCalendarAccount($accountKey);
			#var_dump($calendarAccount);
			
			#$courseBool = get_option($this->prefix."courseBool", "false");
			#$courseName = get_option($this->prefix."courseName", "false");
			$dateFormat = get_option($this->prefix."dateFormat", "0");
			$courseBool = "false";
			if(intval($calendarAccount["courseBool"]) == 1){
				
				$courseBool = "true";
				
			}
			
			$locale = get_locale();
			$dictionary = $this->getDictionary("display_booking_page", $this->plugin_name);
			
			$localize_script = array(
				'url' => admin_url('admin-ajax.php'), 
				'action' => $this->action_public, 
				'nonce' => wp_create_nonce($this->action_public."_ajax"), 
				'courseBool' => $courseBool, 
				'courseName' => $calendarAccount["courseTitle"], 
				'year' => date('Y'), 
				'month' => date('m'), 
				'day' => date('d'), 
				'courseList' => $courseList, 
				'currency' => $list['General']['booking_package_currency']['value'],
				'dateFormat' => $dateFormat,
				'formData' => $formData,
				'locale' => $locale,
				'accountKey' => $accountKey
			);
			
			
			if(intval(get_option($this->prefix."stripe_active", 0)) == 1){
				
				$stripe_public_key = get_option($this->prefix."stripe_public_key", null);
				if(!is_null($stripe_public_key)){
					
					$localize_script['stripe_active'] = 1;
					$localize_script['stripe_public_key'] = $stripe_public_key;
					wp_enqueue_script('stripe_checkout_v3_js', 'https://js.stripe.com/v3/');
					
				}else{
					
					$localize_script['stripe_active'] = 0;
					
				}
				
			}else{
				
				$localize_script['stripe_active'] = 0;
				
			}
			
			wp_enqueue_script( 'i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js');
			wp_enqueue_script( 'XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js');
			#wp_enqueue_script( 'Confirm_js', plugin_dir_url( __FILE__ ).'js/Confirm.js');
			wp_enqueue_script( 'Input_js', plugin_dir_url( __FILE__ ).'js/Input.js');
			wp_enqueue_script( 'Calendar_js', plugin_dir_url( __FILE__ ).'js/Calendar.js');
			wp_enqueue_style( 'booking_app_js_css', plugin_dir_url( __FILE__ ).'css/Booking_app.css' );
			wp_enqueue_style('https://fonts.googleapis.com/icon?family=Material+Icons');
			#$parse_url = parse_url($booking_package_path);
			wp_enqueue_script('booking_app_js', plugin_dir_url( __FILE__ ).'js/Booking_app.js');
			wp_localize_script('booking_app_js', $this->prefix.'dictionary', $dictionary);
			wp_localize_script('booking_app_js', 'reservation_info', $localize_script);
			
			
			
			$html = '<div id="bookingBlockPanel" class="hidden_panel"><img src="'.plugin_dir_url( __FILE__ ).'images/loading_0.gif"></img></div>';
			$html .= '<div id="calendarPage"></div>';
			$html .= '<div id="schedulePage" class="hidden_panel"></div>';
			$html .= '<div id="inputFormPanel" class="hidden_panel"></div>';
			#$html .= "<div>予約ページのテスト</div>";
			
			return $html;
			
		}
		
		public function admin_bar_menu($wp_admin_bar){
			
			wp_enqueue_style( 'control_css', plugin_dir_url( __FILE__ ).'css/control.css' );
			$title = '<span class="top_toolbar_icon"></span><span>'.__("Booking Package", $this->plugin_name).'</span>';
			$plugin_top_bar = $this->plugin_name.'_top_bar';
			$args = array(
							"id" => $plugin_top_bar,
							"meta" => array(), 
							'title' => $title,
							'href' => admin_url("admin.php?page=".$this->plugin_name."/index.php")
						);
						
			$wp_admin_bar->add_node($args);
			$args = array(
							"id" => $plugin_top_bar."_report",
							"parent" => $plugin_top_bar, 
							"meta" => array(), 
							'title' => __('Report & Booking', $this->plugin_name),
							'href' => admin_url("admin.php?page=".$this->plugin_name."/index.php")
						);
						
			$wp_admin_bar->add_node($args);
			
			$args = array(
							"id" => $plugin_top_bar."_schedule",
							"parent" => $plugin_top_bar, 
							"meta" => array(), 
							'title' => __('Calendar Setting', $this->plugin_name),
							'href' => admin_url("admin.php?page=".$this->plugin_name."_schedule_page")
						);
			$wp_admin_bar->add_node($args);
			
			$args = array(
							"id" => $plugin_top_bar."_setting",
							"parent" => $plugin_top_bar, 
							"meta" => array(), 
							'title' => __('General Setting', $this->plugin_name),
							'href' => admin_url("admin.php?page=".$this->plugin_name."_setting_page")
						);
			$wp_admin_bar->add_node($args);
				
			
		}
		
		public function add_pages() {
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			$setting = new setting($this->prefix, $this->plugin_name);
			$setting->updateChannelGC();
			
			$plugin_name = $this->plugin_name.'_admin';
			/**
			add_menu_page($plugin_name, __('Booking Package', $this->plugin_name), 'level_8', $this->plugin_name.'_report_and_booking', array($this,'adomin'), 'dashicons-calendar-alt', 26);
			add_submenu_page(__FILE__, $plugin_name, __('Report & Booking', $this->plugin_name),  'level_8', $this->plugin_name.'_report_and_booking', array($this,'adomin'));
			add_submenu_page(__FILE__, $plugin_name, __('Schedule', $this->plugin_name),  'edit_themes', $this->plugin_name.'_schedule_page', array($this,'schedule_page'));
			add_submenu_page(__FILE__, $plugin_name, __('General Setting', $this->plugin_name),  'edit_themes', $this->plugin_name.'_setting_page', array($this,'setting_pange'));
			**/
			add_menu_page($plugin_name, __('Booking Package', $this->plugin_name), 'level_8', __FILE__, array($this,'adomin'), 'dashicons-calendar-alt', 26);
			add_submenu_page(__FILE__, $plugin_name, __('Report & Booking', $this->plugin_name),  'level_8', __FILE__, array($this,'adomin'));
			add_submenu_page(__FILE__, $plugin_name, __('Calendar Setting', $this->plugin_name),  'edit_themes', $this->plugin_name.'_schedule_page', array($this,'schedule_page'));
			add_submenu_page(__FILE__, $plugin_name, __('General Setting', $this->plugin_name),  'edit_themes', $this->plugin_name.'_setting_page', array($this,'setting_pange'));
		}
		
		
		
		public function adomin() {
			
			#$timezone = get_option('timezone_string');
            #date_default_timezone_set($timezone);
            #$this->activation("activation");
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Webhook.php');
            require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			
			$setting = new setting($this->prefix, $this->plugin_name);
			$list = $setting->getList();
			$courseList = $setting->getCourseList();
			$emailMessageList = $setting->getEmailMessage(array('enable'));
			$formData = $setting->getForm();
			
			$courseBool = get_option($this->prefix."courseBool", "false");
			$courseName = get_option($this->prefix."courseName", "false");
			$dateFormat = get_option($this->prefix."dateFormat", "0");
			$locale = get_locale();
			
			
			
			
			$timeMin = date('U') - (7 * 24 * 60 * 60);
            
            $webhook = new Webhook($this->prefix, $this->plugin_name);
            $webhook->catchWebhook("", "", "", "");
            
            $schedule = new Schedule($this->prefix, $this->plugin_name);
            $schedule->deleteOldDaysInSchedules();
            $schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
            #$schedule->retryToSendToServer();
            
            $dictionary = $this->getDictionary("adomin", $this->plugin_name);
			
			$localize_script = array(
									'url' => admin_url('admin-ajax.php'), 
									'action' => $this->action_control, 
									'nonce' => wp_create_nonce($this->action_control."_ajax"), 
									'prefix' => $this->prefix,
									'courseBool' => $courseBool, 
									'courseName' => $courseName, 
									'year' => date('Y'), 
									'month' => date('m'), 
									'day' => date('d'), 
									'locale' => $locale,
									'courseList' => $courseList, 
									'currency' => $list['General']['booking_package_currency']['value'],
									'dateFormat' => $dateFormat,
									'formData' => $formData,
									'calendarAccountList' => $schedule->getCalendarAccountListData()
								);
			$localize_script['emailEnable'] = $emailMessageList;
            
			wp_enqueue_style( 'control_css', plugin_dir_url( __FILE__ ).'css/control.css' );
			wp_enqueue_style( 'control_for_madia_css', plugin_dir_url( __FILE__ ).'css/control_for_madia.css' );
			wp_enqueue_script( 'i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js');
			wp_enqueue_script( 'XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js');
			wp_enqueue_script( 'Confirm_js', plugin_dir_url( __FILE__ ).'js/Confirm.js');
			wp_enqueue_script( 'Input_js', plugin_dir_url( __FILE__ ).'js/Input.js');
			wp_enqueue_script( 'Calendar_js', plugin_dir_url( __FILE__ ).'js/Calendar.js');
			wp_enqueue_script( 'Reservation_manage_js', plugin_dir_url( __FILE__ ).'js/Reservation_manage.js');
			
			#var_dump($localize_script);
			wp_localize_script('Reservation_manage_js', $this->prefix.'dictionary', $dictionary);
			wp_localize_script('Reservation_manage_js', 'schedule_data', $localize_script);
			wp_enqueue_script( 'Reservation_manage_js' );
			
			
			$isExtensionsValid = $setting->extensionFunction();
			
			$updated_style = "display: none;";
			$control_panel_button_style = "display: none;";
			$user = wp_get_current_user();
			#if(!empty($_POST) && current_user_can("level_8") === true){
			if(!empty($_POST) && $user->allcaps['manage_options'] === true){
				
				if(check_admin_referer('booking_package_action', 'booking_package_nonce_field')){
					
					
					
				}
				
			}
			
			$active = get_option("booking_package_active", 0);
			$booking_package_id = get_option("booking_package_id", "");
			$booking_package_path = get_option("booking_package_path", "");
			$booking_package_script_path = get_option("booking_package_script_path", "");
			$booking_package_serial = get_option("booking_package_serial", "");
			
			if(!empty($booking_package_script_path)){
				
				$control_panel_button_style = "";
				
			}
			
			$pluginName = $this->plugin_name;
			
			#print '<div class="wrap">';
			#print '<div id="select_package" class="welcome-panel"><div>';
			#print '<button id="save_setting" type="button" class="w3tc-button-save button-primary" onclick="editTemplateSchedule(0)">Edit schedule</button>';
			#print '<div id="calendarPage"></div>';
			
			
			
			
			
			?>
			<div class="wrap">
				<div class="top_bar">
					<!--
					<h1 class="wp-heading-inline top_title_h1"><?php _e("Report & booking", $pluginName); ?></h1>
					-->
					<?php
						
					$this->upgradeButton($isExtensionsValid);
						
					?>
				</div>
				<div class="<?php print $update_class; ?> settings-error notice is-dismissible" id="res" style="<?php print $updated_style; ?>"><?php print $update_value; ?></div>
				
				<div id="select_package" class="welcome-panel">
					<div id="calendarPage"></div>
				</div>
				
				<div id="editPanel" class="edit_modal hidden_panel">
					<button type="button" id="media_modal_close" class="media_modal_close">
						<span class="media_modal_icon">
							<span class="screen_reader_text">Close</span>
						</span>
					</button>
					<div class="edit_modal_content">
						<div id="menu_panel" class="media_frame_menu">
							<div id="media_menu" class="media_menu"></div>
						</div>
						<div id="media_title" class="media_frame_title"><h1 id="edit_title"></h1></div>
						<div id="media_router" class="media_frame_router">
							<div class="reservation_table_row">
								<div id="reservation_users" class="media_menu_item active"><?php _e("Booking users", $pluginName); ?></div>
								<div id="add_reservation" class="media_menu_item"><?php _e("Make Booking", $pluginName); ?></div>
							</div>
						</div>
						<div id="media_frame_reservation_content"></div>
						<div id="frame_toolbar" class="media_frame_toolbar">
							<div class="media_toolbar">
								<div id="buttonPanel" class="media_toolbar_primary" style="float: initial;">
									
									<div id="leftButtonPanel"></div>
									<div id="rightButtonPanel"></div>
									
								</div>
							</div>
						</div>
						
					</div>
					
				</div>
				
				<div id="blockPanel" class="edit_modal_backdrop hidden_panel"></div>
				
				<div id="dialogPanel" class="hidden_panel">
					<div class="blockPanel"></div>
					<div class="confirmPanel">
						<div class="subject"><?php _e("Title", $pluginName); ?></div>
						<div class="body"><?php _e("Message", $pluginName); ?></div>
						<div class="buttonPanel">
							<button id="dialogButtonYes" type="button" class="yesButton button button-primary"><?php _e("Yes", $pluginName); ?></button>
							<button id="dialogButtonNo" type="button" class="noButton button button-primary"><?php _e("No", $pluginName); ?></button>
						</div>
					</div>
				</div>
				
			<!-- /.wrap -->
			</div>	
			<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="<?php print plugin_dir_url( __FILE__ ); ?>images/loading_0.gif"></div>
			
			<?php
			
			#print '<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="'.plugin_dir_url( __FILE__ ).'images/loading_0.gif"></div>';
			
		}
		
		public function schedule_page(){
			
			$this->update_database();
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			
			$timezone = get_option('timezone_string');
            date_default_timezone_set($timezone);
			
			$setting = new setting($this->prefix, $this->plugin_name);
			$courseData = $setting->getCourseData();
			$formInputType = $setting->getFormInputType();
			
			$emailMessageList = $setting->getEmailMessage();
			#$mailSetting = $setting->getEmailMessageList(1);
			
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$schedule->deleteOldDaysInSchedules();
			$schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
			#$list = $schedule->getTemplateSchedule(0);
			#var_dump($list);
			
			$dateFormat = get_option($this->prefix."dateFormat", "0");
			$courseBool = get_option($this->prefix."courseBool", "false");
			$locale = get_locale();
			
			$dictionary = $this->getDictionary("schedule_page", $this->plugin_name);
			$elementForCalendarAccount = $setting->getElementForCalendarAccount();
			if($this->calendarAccountType == 0){
				
				unset($elementForCalendarAccount['type']);
				
			}
			
			$localize_script = array(
				'url' => admin_url('admin-ajax.php'), 
				'action' => $this->action_control, 
				'nonce' => wp_create_nonce($this->action_control."_ajax"), 
				'courseBool' => $courseBool, 
				'year' => date('Y'), 
				'month' => date('m'), 
				'locale' => $locale, 
				'dateFormat' => $dateFormat, 
				'list' => $list, 
				'formInputType' => $formInputType, 
				'courseData' => $courseData,
				'elementForCalendarAccount' => $elementForCalendarAccount, 
				'calendarAccountType' => $this->calendarAccountType
			);
			
			wp_print_scripts( array( 'jquery-ui-sortable' ));
			wp_enqueue_style( 'control_css', plugin_dir_url( __FILE__ ).'css/control.css' );
			wp_enqueue_style( 'control_for_madia_css', plugin_dir_url( __FILE__ ).'css/control_for_madia.css' );
			wp_enqueue_script( 'i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js');
			wp_enqueue_script( 'XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js');
			wp_enqueue_script( 'Confirm_js', plugin_dir_url( __FILE__ ).'js/Confirm.js');
			wp_enqueue_script( 'Calendar_js', plugin_dir_url( __FILE__ ).'js/Calendar.js');
			wp_enqueue_script( 'input_js', plugin_dir_url( __FILE__ ).'js/Input.js');
			wp_enqueue_script( 'schedule_pange', plugin_dir_url( __FILE__ ).'js/Schedule.js', array('jquery'));
			wp_localize_script('schedule_pange', $this->prefix.'dictionary', $dictionary);
			wp_localize_script('schedule_pange', 'schedule_data', $localize_script);
			
			
			$isExtensionsValid = $setting->extensionFunction();
			$pluginName = $this->plugin_name;
			
			?>
				
				<div id="select_package" class="wrap">
					<div class="top_bar">
						<!--
						<h1 class="wp-heading-inline top_title_h1"><?php _e("Schedule setting", $pluginName); ?></h1>
						-->
						
					</div>
					<!-- <div id="select_package" class="welcome-panel"><div>  -->
					<!-- <div id="select_package"></div> -->
					
					
							<div id="calendarAccountList">
								<div class="actionButtonPanel">
									<button id="add_new_calendar" type="button" class="w3tc-button-save button-primary" style="margin-right: 10px;"><?php _e("Add new calendar", $pluginName); ?></button>
									<?php
									
										$this->upgradeButton($isExtensionsValid);
									
									?>
								</div>
								<table id="calendar_list_table" class="wp-list-table widefat fixed striped"></table>
								
							</div>
							<div id="tabFrame" class="hidden_panel">
								<div class="actionButtonPanel">
									<button id="return_to_calendar_list" type="button" class="w3tc-button-save button-primary" style="margin-right: 10px;"><?php _e("Return to Calendar list", $pluginName); ?></button>
									
								</div>
								
								<div style="overflow-x: auto;">
									<div class="menuList">
										<div id="calendarLink" class="menuItem active"><?php _e("Schedule", $pluginName); ?></div>
										<div id="formLink" class="menuItem"><?php _e("Form fields", $pluginName); ?></div>
										<div id="courseLink" class="menuItem"><?php _e("Services", $pluginName); ?></div>
										<div id="emailLink" class="menuItem"><?php _e("Emails message", $pluginName); ?></div>
										<div id="settingLink" class="menuItem"><?php _e("Setting", $pluginName); ?></div>
									</div>
								</div>
								<div id="contentPanel" class="content">
									<div id="calendarPage"></div>
									<div id="formPanel" class="hidden_panel">formPanel</div>
									<div id="coursePanel" class="hidden_panel">coursePanel</div>
									<div id="emailPanel" class="hidden_panel">
										<div id="mailSettingPanel">
											<div id="mailSettingButtonPanel"></div>
											<div id="content_area"></div>
										</div>
									</div>
									<div id="settingPanel" class="hidden_panel"></div>
								</div>
							
							</div>
						
					
				</div>
				
				<div id="editPanel" class="edit_modal hidden_panel">
					<button type="button" id="media_modal_close" class="media_modal_close">
						<span class="media_modal_icon">
							<span class="screen_reader_text">Close</span>
						</span>
					</button>
					<div class="edit_modal_content">
						<div id="menu_panel" class="media_frame_menu">
							<div id="media_menu" class="media_menu"></div>
						</div>
						<div id="media_title" class="media_frame_title"><h1 id="edit_title"></h1></div>
						<div id="media_router" class="media_frame_router">
							<table class="tableNameList">
								
								<tr>
									<th>No</th>
									<td class="timeTd"><?php _e("Time", $pluginName); ?></td>
									<td><?php _e("Title", $pluginName); ?></td>
									<td class="td_width_50_px"><?php _e("Capacity", $pluginName); ?></td>
									<td id="remainder" class="td_width_50_px"><?php _e("Remainder", $pluginName); ?></td>
									<td id="stop" class="td_width_50_px"><?php _e("Stop", $pluginName); ?></td>
									<td id="delete" class="td_width_50_px"><?php _e("Delete", $pluginName); ?></td>
								</tr>
								
							</table>
							
						</div>
						<div id="media_frame_content"></div>
						
						
						<div id="email_edit_panel" class="media_left_zero hidden_panel">
							
							<div class="mail_message_area_left">
								<div class="enablePanel">
									<div class="enableLabel"><?php _e("Enable / Disable", $pluginName); ?></div>
									<div class="enableValuePanel">
										<label><input type="checkbox" id="mailEnable"/> <?php _e("Enable this email notification", $pluginName); ?></label>
									</div>
								</div>
								<div class="emailFormatPanel">
									<div class="emailFormatLabel"><?php _e("Email format", $pluginName); ?></div>
									<div class="emailFormatValuePanel">
										<label style="margin-right: 10px;"><input type="radio" id="emailFormatHtml" name="emailFormat" /> HTML</label>
										<label><input type="radio" id="emailFormatText" name="emailFormat" /> TEXT</label>
									</div>
								</div>
								<div>
									<input type="text" id="subject" class="mail_subject">
								</div>
								<?php 
									
									print '<div id="emailContentPanel" class="text_editer_panel">';
									wp_editor("Content", "emailContent", array('media_buttons' => FALSE, 'textarea_rows' => 15)); 
									print '</div>';
									/**
									foreach($emailMessageList as $key => $mailMessage){
										
										$value = stripslashes($mailMessage['content']);
										print '<div id="'.$key.'_panel" class="text_editer_panel">';
										wp_editor($value, $key, array('media_buttons' => FALSE, 'textarea_rows' => 15)); 
										print '</div>';
										
									}
									**/
									
								?>
							</div>
							<div id="mail_message_area_right" class="mail_message_area_right"></div>
							
						</div>
						
						<div id="frame_toolbar" class="media_frame_toolbar">
							<div class="media_toolbar">
								<div id="buttonPanel" class="media_toolbar_primary">
									
								</div>
							</div>
						</div>
						
					</div>
					
				</div>
				
				<div id="blockPanel" class="edit_modal_backdrop hidden_panel"></div>
				
				<div id="timeSelectPanel" class="hidden_panel">
					<div class="blockPanel"></div>
					
					<div id="selectPanelForConfirm" class="selectPanel">
						<div id="arror"></div>
						<div class="subject"><?php _e("Title", $pluginName); ?></div>
						<div id="confirm_body" class="body"></div>
						<div class="buttonPanel scheduleButtonPanel">
							<button id="dialogButtonReset" type="button" class="yesButton button button-primary" style="width: 70px; margin: 0;"><?php _e("Reset", $pluginName); ?></button>
							<button id="dialogButtonDone" type="button" class="noButton button button-primary" style="width: 70px; margin: 0;"><?php _e("Close", $pluginName); ?></button>
						</div>
					</div>
					
				</div>
				
				<div id="dialogPanel" class="hidden_panel">
					<div class="blockPanel"></div>
					<div class="confirmPanel">
						<div class="subject"><?php _e("Title", $pluginName); ?></div>
						<div class="body"><?php _e("Message", $pluginName); ?></div>
						<div class="buttonPanel">
							<button id="dialogButtonYes" type="button" class="yesButton button button-primary"><?php _e("Yes", $pluginName); ?></button>
							<button id="dialogButtonNo" type="button" class="noButton button button-primary"><?php _e("No", $pluginName); ?></button>
						</div>
					</div>
				</div>
				
				
			
			<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="<?php print plugin_dir_url( __FILE__ ); ?>images/loading_0.gif"></div>
				
			<?php
			
			#print '<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="'.plugin_dir_url( __FILE__ ).'images/loading_0.gif"></div>';
			
		}
		
		public function setting_pange(){
			
			/**
			var_dump(get_option('date_format'));
			print date_i18n(get_option('date_format') ,strtotime("11/15-1976"));
			**/
			
			$this->update_database();
			$timezone = get_option('timezone_string');
			#var_dump($timezone);
			date_default_timezone_set($timezone);
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			$setting = new setting($this->prefix, $this->plugin_name);
			
			$list = $setting->getList();
			$booking_sync = $setting->getBookingSyncList();
			$emailMessageList = $setting->getEmailMessage();
			$courseList = $setting->getCourseList();
			$courseData = $setting->getCourseData();
			$formInputType = $setting->getFormInputType();
			$formData = $setting->getForm();
			$countries = json_decode(file_get_contents(plugin_dir_path( __FILE__ ).'lib/Countries_with_Regional_Codes.json'), true);
			$list['General'][$this->prefix.'country']['valueList'] = $countries;
			
			$booking_sync['Google_Calendar']['parse_url'] = parse_url(get_home_url());
			$booking_sync['iCal']['booking_package_ical_token']['home'] = get_home_url();
			if(is_null($booking_sync['iCal']['booking_package_ical_token']['value']) === true || strlen($booking_sync['iCal']['booking_package_ical_token']['value']) == 0){
				
				$tokenResponse = $setting->refreshToken("booking_package_ical_token");
				$booking_sync['iCal']['booking_package_ical_token']['value'] = $tokenResponse['token'];
				
			}
			
			wp_enqueue_style( 'setting_pange', plugin_dir_url( __FILE__ ).'css/control.css');
			wp_enqueue_style( 'control_for_madia_css', plugin_dir_url( __FILE__ ).'css/control_for_madia.css' );
			
			$locale = get_locale();
			$dictionary = $this->getDictionary("setting_pange", $this->plugin_name);
			
			$localize_script = array(
				'url' => admin_url('admin-ajax.php'), 
				'action' => $this->action_control, 
				'nonce' => wp_create_nonce($this->action_control."_ajax"), 
				'locale' => $locale,
				'list' => $list, 'bookingSyncList' => $booking_sync, 
				"extension_url" => BOOKING_PACKAGE_EXTENSION_URL, 
				'courseData' => $courseData, 
				'courseList' => $courseList, 
				'formInputType' => $formInputType, 
				'formData' => $formData, 
				'emailMessageList' => $emailMessageList
			);
			$subscriptions = $this->getSubscriptions();
			foreach($subscriptions as $key => $value){
				
				if($key == 'expiration_date_for_subscriptions'){
					
					$localize_script['expiration_date'] = date('F d, Y H:i', $value);
					
				}
				
				$localize_script[$key] = $value;
				
			}
			
			
			
			$isExtensionsValid = $setting->extensionFunction();
			#print "isExtensionsValid = ".$isExtensionsValid."<br>";
			
			wp_print_scripts( array( 'jquery-ui-sortable' ));
			wp_enqueue_script( 'i18n_js', plugin_dir_url( __FILE__ ).'js/i18n.js');
			wp_enqueue_script( 'XMLHttp_js', plugin_dir_url( __FILE__ ).'js/XMLHttp.js');
			wp_enqueue_script( 'input_js', plugin_dir_url( __FILE__ ).'js/Input.js');
			wp_enqueue_script( 'Confirm_js', plugin_dir_url( __FILE__ ).'js/Confirm.js');
			wp_enqueue_script( 'setting_pange', plugin_dir_url( __FILE__ ).'js/setting.js', array('jquery'));
			wp_localize_script('setting_pange', $this->prefix.'dictionary', $dictionary);
			wp_localize_script('setting_pange', 'setting_data', $localize_script);
			wp_localize_script('setting_pange', $this->prefix.'countries', $countries);
			
			$pluginName = $this->plugin_name;
			
			
			?>
				<div class="wrap">
					<div id="tabFrame">
						<div style="overflow-x: auto;">
						<div class="menuList">
							<div id="settingLink" class="menuItem active"><?php _e("Setting", $pluginName); ?></div>
							
							<!--
							<div id="formLink" class="menuItem"><?php _e("Form fields", $pluginName); ?></div>
							<div id="courseLink" class="menuItem"><?php _e("Services", $pluginName); ?></div>
							<div id="emailLink" class="menuItem"><?php _e("Emails message", $pluginName); ?></div>
							-->
							
							<div id="syncLink" class="menuItem"><?php _e("Sync", $pluginName); ?></div>
							<div id="subscriptionLink" class="menuItem"><?php _e("Subscription details", $pluginName); ?></div>
						</div>
						</div>
						<div id="contentPanel" class="content">
							<div id="settingPanel">
								<div id="setting_table"></div>
								<div><button id="save_setting" type="button" class="w3tc-button-save button-primary"><?php _e("Save all settings", $pluginName); ?></button></div>
							</div>
							<!--
							<div id="formPanel" class="hidden_panel">formPanel</div>
							<div id="coursePanel" class="hidden_panel">coursePanel</div>
							<div id="emailPanel" class="hidden_panel">
								<div id="mailSettingPanel">
									
									<div id="mailSettingButtonPanel"></div>
										
									<div id="content_area">
										
									</div>
									<div>
										
										
									</div>
								</div>
							</div>
							-->
							<div id="syncPanel" class="hidden_panel">
								<div id="bookingSync_table"></div>
								<div><button id="save_bookingSync" type="button" class="w3tc-button-save button-primary"><?php _e("Save all settings", $pluginName); ?></button></div>
							</div>
							<div id="subscriptionPanel" class="hidden_panel"></div>
							
						</div>
					</div>
					
				</div>
				
				
				<div id="editPanel" class="edit_modal hidden_panel">
					<button type="button" id="media_modal_close" class="media_modal_close">
						<span class="media_modal_icon">
							<span class="screen_reader_text">Close</span>
						</span>
					</button>
					<div class="edit_modal_content">
						<div id="media_title" class="media_left_zero"><h1 id="edit_title"></h1></div>
						<div id="media_router" class="media_left_zero">
							<div class="table_row">
								
							</div>
						</div>
						<div id="media_frame_content" class="media_left_zero content_top_48">
							
							<!--
							<div class="mail_message_area_left">
								
								<div class="enablePanel">
									<div class="enableLabel"><?php _e("Enable / Disable", $pluginName); ?></div>
									<div class="enableValuePanel">
										<label><input type="checkbox" id="mailEnable"/> <?php _e("Enable this email notification", $pluginName); ?></label>
									</div>
								</div>
								<div class="emailFormatPanel">
									<div class="emailFormatLabel"><?php _e("Email format", $pluginName); ?></div>
									<div class="emailFormatValuePanel">
										<label style="margin-right: 10px;"><input type="radio" id="emailFormatHtml" name="emailFormat" /> HTML</label>
										<label><input type="radio" id="emailFormatText" name="emailFormat" /> TEXT</label>
									</div>
								</div>
								<div>
									<input type="text" id="subject" class="mail_subject">
								</div>
								<?php 
									
									foreach($emailMessageList as $key => $mailMessage){
										
										$value = stripslashes($mailMessage['content']);
										print '<div id="'.$key.'_panel" class="text_editer_panel">';
										wp_editor($value, $key, array('media_buttons' => FALSE, 'textarea_rows' => 15)); 
										print '</div>';
										
									}	
								?>
							</div>
							<div id="mail_message_area_right" class="mail_message_area_right">
								
							</div>
							-->
						</div>
						<div id="frame_toolbar" class="media_frame_toolbar media_left_zero">
							<div class="media_toolbar">
								<div class="media_toolbar_primary">
									<button id="mail_message_save_button" type="button" class="button media-button button-primary button-large media-button-insert"><?php _e("Save", $pluginName); ?></button>
								</div>
							</div>
						</div>
						
					</div>
					
				</div>
				
				<div id="blockPanel" class="edit_modal_backdrop hidden_panel"></div>
				
				<div id="dialogPanel" class="hidden_panel">
					<div class="blockPanel"></div>
					<div class="confirmPanel">
						<div class="subject"><?php _e("Title", $pluginName); ?></div>
						<div class="body"><?php _e("Message", $pluginName); ?></div>
						<div class="buttonPanel">
							<button id="dialogButtonYes" type="button" class="yesButton button button-primary"><?php _e("Yes", $pluginName); ?></button>
							<button id="dialogButtonNo" type="button" class="noButton button button-primary"><?php _e("No", $pluginName); ?></button>
						</div>
					</div>
				</div>
				
				<div id="google_calendar_api" class="hidden_panel">
					
					<div>
						<?php _e("The Google Calendar API lets you share customer information between the Booking Package and Google Calendar.", $pluginName); ?>
						<?php _e("When you create or edit a new event in Google Calendar, it will also be sent to the booking package.", $pluginName); ?><br>
						<?php _e('For details on how to set up please read that <a id="googleCalendarLink" href="https://saasproject.net/googleCalendar/" target="_blank">how to set up sync for Booking Package and Google Calendar</a>. ', $pluginName); ?>
					</div>
					
				</div>
				
				<div id="loadingPanel" class="loading_modal_backdrop hidden_panel"><img src="<?php print plugin_dir_url( __FILE__ ); ?>images/loading_0.gif"></div>
				
			<?php
			
			
		}
		
		public function update_data($key, $value){
			
			if(get_option($key) === false){
							
				add_option($key, $value);
					
			}else{
				
				update_option($key, $value);
				
			}
			
		}
		
		public function wp_ajax_booking_package_for_public(){
			
			if(isset($_POST['nonce']) && check_ajax_referer($this->action_public."_ajax", 'nonce')){
				
				$timezone = get_option('timezone_string');
            	date_default_timezone_set($timezone);
            	
            	require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
				require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
				require_once(plugin_dir_path( __FILE__ ).'lib/CreditCard.php');
				$schedule = new Schedule($this->prefix, $this->plugin_name);
				
            	$response = array('status' => 'error', 'mode' => $_POST['mode']);
            	
            	if($_POST['mode'] == 'getReservationData'){
            		
					$response = $schedule->getReservationData($_POST['month'], $_POST['day'], $_POST['year'], false, true);
            		
            	}
            	
            	if($_POST['mode'] == 'sendBooking'){
            		
					$response = $schedule->sendBooking();
            		
            	}
            	
				print json_encode($response);
				
			}else{
				
				print json_decode(array('status' => 'error'));
				
			}
			
			die();
			
		}
		
		public function wp_ajax_booking_package(){
			
			if(isset($_POST['nonce']) && check_ajax_referer($this->action_control."_ajax", 'nonce')){
				
				$timezone = get_option('timezone_string');
            	date_default_timezone_set($timezone);
				
				$response = array('status' => 'error', 'mode' => $_POST['mode']);
				
				require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
				require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
				require_once(plugin_dir_path( __FILE__ ).'lib/CreditCard.php');
				
				$setting = new setting($this->prefix, $this->plugin_name);
				
				if($_POST['mode'] == 'setting'){
					
					$response = $setting->update($_POST);
					$response['status'] = 'success';
					
				}
				
				if($_POST['mode'] == 'refreshToken'){
					
					$response = $setting->refreshToken($_POST['key']);
					
				}
				
				if($_POST['mode'] == 'getCourseList'){
					
					$response = $setting->getCourseList($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'addCourse'){
					
					$response = $setting->addCourse($_POST);
					
				}
				
				if($_POST['mode'] == 'updateCourse'){
					
					$response = $setting->updateCourse($_POST);
					
				}
				
				if($_POST['mode'] == 'deleteCourse'){
					
					$response = $setting->deleteCourse($_POST);
					
				}
				
				if($_POST['mode'] == 'changeCourseRank'){
					
					$response = $setting->changeCourseRank($_POST);
					
				}
				
				if($_POST['mode'] == 'getForm'){
					
					$response = $setting->getForm($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'addForm'){
					
					$response = $setting->addForm($_POST);
					
				}
				
				if($_POST['mode'] == 'updateForm'){
					
					$response = $setting->updateForm($_POST);
					
				}
				
				if($_POST['mode'] == 'deleteFormItem'){
					
					$response = $setting->deleteFormItem($_POST);
					
				}
				
				if($_POST['mode'] == 'changeFormRank'){
					
					$response = $setting->changeFormRank($_POST);
					
				}
				
				if($_POST['mode'] == 'updataEmailMessageForCalendarAccount'){
					
					$response = $setting->updataEmailMessageForCalendarAccount();
					
				}
				
				if($_POST['mode'] == 'updataEmailMessage'){
					
					$response = $setting->updataEmailMessage($_POST['key'], $_POST['subject'], $_POST['content'], $_POST['enable'], $_POST['format']);
					
				}
				
				if($_POST['mode'] == 'upgradePlan'){
					
					$response = $setting->upgradePlan($_POST['type']);
					
				}
				
				if($_POST['mode'] == 'getEmailMessageList' && isset($_POST['accountKey'])){
					
					$response = $setting->getEmailMessageList($_POST['accountKey']);
					
				}
				
				if($_POST['mode'] == 'getTemplateSchedule'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->getTemplateSchedule($_POST['weekKey']);
					
				}
				
				if($_POST['mode'] == 'getPublicSchedule'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->getPublicSchedule();
					
				}
				
				if($_POST['mode'] == 'getCalendarAccountListData'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->getCalendarAccountListData();
					
				}
				
				if($_POST['mode'] == 'addCalendarAccount'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->addCalendarAccount();
					
				}
				
				if($_POST['mode'] == 'updateCalendarAccount'){
					
					if($this->calendarAccountType == 0){
						
						$_POST['type'] = 'day';
						
					}
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->updateCalendarAccount();
					
				}
				
				if($_POST['mode'] == 'deleteCalendarAccount'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->deleteCalendarAccount();
					
				}
				
				if($_POST['mode'] == 'getAccountScheduleData'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->getAccountScheduleData();
					
				}
				
				if($_POST['mode'] == 'updateAccountTemplateSchedule'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$list = $schedule->updateAccountTemplateSchedule();
					
					$response['status'] = 'success';
					
				}
				
				if($_POST['mode'] == 'updateAccountSchedule'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$list = $schedule->updateAccountSchedule();
					
					$response['status'] = 'success';
					
				}
				
				if($_POST['mode'] == 'getReservationData'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					if(isset($_POST['accountKey'])){
						
						#booking_package_accountKey
						$expire = date('U') + (30 * 24 * 3600);
						setcookie($this->prefix.'accountKey', $_POST['accountKey'], $expire);
						$response = $schedule->getReservationData($_POST['month'], $_POST['day'], $_POST['year']);
						$response['formData'] = $setting->getForm($_POST['accountKey']);
						$response['courseList'] = $setting->getCourseList($_POST['accountKey']);
						
					}else{
						
						$response = $schedule->getReservationData($_POST['month'], $_POST['day'], $_POST['year']);
						
					}
					
					
					
				}
				
				if($_POST['mode'] == 'sendBooking'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->sendBooking();
					
				}
				
				if($_POST['mode'] == 'deleteBookingData'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->deleteBookingData($_POST['key']);
					
				}
				
				if($_POST['mode'] == 'updateBooking'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->updateBooking();
					
				}
				
				if($_POST['mode'] == 'updateStatus'){
					
					$schedule = new Schedule($this->prefix, $this->plugin_name);
					$response = $schedule->updateStatus();
					
				}
				
				print json_encode($response);
				
			}
			
			die();
			
		}
		
		public function license_check($id, $booking_package_serial){
			
			$bool = false;
			$params = array('id' => $id, 'serial' => $booking_package_serial);
			
			$curl = curl_init();
			curl_setopt($curl, CURLOPT_URL, "https://www.cartmaker.net/control/license_wp/");
			curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($params));
			curl_setopt($curl, CURLOPT_POST, true);
			
			$response = curl_exec($curl);
			$result = json_decode($response);
			$httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
			curl_close ($curl);
			
			if(isset($result->path)){
				
				$path = (string) $result->path;
				return $path;
				
			}
			
			#var_dump((string) $result->path);
			
			return $bool;
			
		}
		
		public function control_panel_check($booking_package_path){
			
			#databaseCheck
			$params = array('check' => 'databaseCheck');
			$bool = false;
			$curl = curl_init();
			curl_setopt($curl, CURLOPT_URL, $booking_package_path."control.php");
			curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($params));
			curl_setopt($curl, CURLOPT_POST, true);
			
			$response = curl_exec($curl);
			$result = json_decode($response);
			$httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
			
			if($httpCode == 200){
				
				return array('id' => $result->license, 'serial' => $result->serial);
				
			}
			
			return $bool;
			
		}
		
		public function getSubscriptions(){
			
			$setting = new setting($this->prefix, $this->plugin_name);
			$subscriptions = $setting->upgradePlan('get');
			unset($subscriptions["status"]);
			return $subscriptions;
			
		}
		
		public function upgradeButton($isExtensionsValid = false){
			
			if($isExtensionsValid === true){
				
				return $isExtensionsValid;
				
			}
			
			$locale = get_locale();
			$dictionary = $this->getDictionary("Upgrade_js", $this->plugin_name);
			
			$timezone = get_option('timezone_string');
			#print get_locale();
			#print get_site_url();
			$upgradeDetail = array("extension_url" => BOOKING_PACKAGE_EXTENSION_URL, "timeZone" => get_option('timezone_string'), "local" => get_locale(), "site" => get_site_url(), "stripe_public_key" => BOOKING_PACKAGE_STRIPE_PUBLIC_KEY, "locale" => $locale);
			
			$subscriptions = $this->getSubscriptions();
			foreach($subscriptions as $key => $value){
				
				$upgradeDetail[$key] = $value;
				
			}
			
			wp_enqueue_script('stripe_checkout_js', 'https://checkout.stripe.com/checkout.js');
			wp_enqueue_script('stripe_checkout_v3_js', 'https://js.stripe.com/v3/');
			wp_enqueue_script('Upgrade_js', plugin_dir_url( __FILE__ ).'js/Upgrade.js');
			wp_localize_script('Upgrade_js', $this->prefix.'upgrade_dictionary', $dictionary);
			wp_localize_script('Upgrade_js', 'upgradeDetail', $upgradeDetail);
			
			$pluginName = $this->plugin_name;
			
			print '<button id="upgradeButton" class="media-button button-primary button-large media-button-insert">'.__('Upgrade', $pluginName).'</button>';
			?>
			
			<div id="upgradePanel" class="edit_modal hidden_panel">
				<button type="button" id="upgrade_media_modal_close" class="media_modal_close">
					<span class="media_modal_icon"><span class="screen_reader_text">Close</span></span>
				</button>
				<div class="edit_modal_content">
					<div id="upgrade_menu_panel" class="media_frame_menu">
						<div id="upgrade_media_menu" class="media_menu"></div>
					</div>
					<div id="upgrade_media_title" class="media_frame_title"><h1 id="upgrade_edit_title"><?php _e('Upgrade', $pluginName); ?></h1></div>
					<div id="upgrade_media_router" class="media_frame_router">
						<div id="upgrade_content_panel">
							
						</div>
					</div>
					<div id="upgrade_frame_toolbar" class="media_frame_toolbar">
						<div class="media_toolbar">
							<div id="upgrade_buttonPanel" class="media_toolbar_primary" style="float: initial;">
								<div id="upgrade_leftButtonPanel"></div>
								<div id="upgrade_rightButtonPanel"></div>
							</div>
						</div>
					</div>
					
				</div>
				
			</div>
			
			<div id="upgrade_blockPanel" class="edit_modal_backdrop hidden_panel"></div>
			
			<?php
			
		}
		
		public function ical_feeds(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Ical.php');
			
			$ical = new iCal($this->prefix);
			$ical->isValid($_GET['ical']);
			
			
			
		}
		
		public function webhook(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Webhook.php');
			
			$target = sanitize_text_field($_GET["weebhook"]);
			$HTTP_X_GOOG_CHANNEL_ID = sanitize_text_field($_SERVER['HTTP_X_GOOG_CHANNEL_ID']);
			$HTTP_X_GOOG_CHANNEL_TOKEN = sanitize_text_field($_SERVER['HTTP_X_GOOG_CHANNEL_TOKEN']);
			
			#if(get_option($this->prefix."id_for_google_webhook") == $HTTP_X_GOOG_CHANNEL_ID && get_option($this->prefix."token_for_google_webhook") == $HTTP_X_GOOG_CHANNEL_ID){
			if(get_option($this->prefix."id_for_google_webhook") == $HTTP_X_GOOG_CHANNEL_ID){
				
				$webhook = new Webhook($this->prefix, $this->plugin_name);
				$webhook->catchWebhook($target, $HTTP_X_GOOG_CHANNEL_ID, $_POST);
				exit;
				
			}
			
			
			
		}
		
		public function api(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			if(isset($_POST['mode'])){
				
				if(isset($_POST['access_status']) && $_POST['access_status'] == 'public'){
					
					if($_POST['mode'] == 'getNonce'){
						
						$response = array(
							'action' => $this->action_public, 
							'nonce' => wp_create_nonce($this->action_public."_ajax"), 
						);
						
						$setting = new setting($this->prefix, $this->plugin_name);
						$list = $setting->getList();
						$courseList = $setting->getCourseList();
						$formData = $setting->getForm();
						
						$schedule = new Schedule($this->prefix, $this->plugin_name);
						$schedule->deleteOldDaysInSchedules();
						$schedule->insertAccountSchedule(date('m'), date('d'), date('Y'));
						
						$courseBool = get_option($this->prefix."courseBool", "false");
						$courseName = get_option($this->prefix."courseName", "false");
						$dateFormat = get_option($this->prefix."dateFormat", "0");
						
						$locale = get_locale();
						$dictionary = $this->getDictionary("display_booking_page", $this->plugin_name);
						
						$localize_script = array(
							'url' => admin_url('admin-ajax.php'), 
							'action' => $this->action_public, 
							'nonce' => wp_create_nonce($this->action_public."_ajax"), 
							'courseBool' => $courseBool, 
							'courseName' => $courseName, 
							'year' => date('Y'), 
							'month' => date('m'), 
							'day' => date('d'), 
							'courseList' => $courseList, 
							'currency' => $list['General']['booking_package_currency']['value'],
							'dateFormat' => $dateFormat,
							'formData' => $formData,
							'locale' => $locale,
							'dictionary' => $dictionary,
						);
						
						if(intval(get_option($this->prefix."stripe_active", 0)) == 1){
							
							$stripe_public_key = get_option($this->prefix."stripe_public_key", null);
							if(!is_null($stripe_public_key)){
								
								$localize_script['stripe_active'] = 1;
								$localize_script['stripe_public_key'] = $stripe_public_key;
								
							}else{
								
								$localize_script['stripe_active'] = 0;
								
							}
							
						}else{
							
							$localize_script['stripe_active'] = 0;
							
						}
						
						print json_encode($localize_script);
						
					}else{
						
						$this->wp_ajax_booking_package_for_public();
						
					}
					
				}
				
				
				exit;
				
			}
			
		}
		
		public function cron_interval(){
			
			$time = 60 * 5;
			$schedules['retry_to_send_to_server'] = array(
        		'interval' => $time,
				'display'  => 'retry_to_send_to_server',
			);
 
    		return $schedules;
			
		}
		
		public function retry_to_send_to_server(){
			
			$name = $this->prefix."retry_to_send_to_server";
			$count = intval(get_option($name, 0));
			$count++;
			if($count == 1){
				
				add_option($name, $count);
				
			}else{
				
				update_option($name, $count);
				
			}
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			
			$timezone = get_option('timezone_string');
            date_default_timezone_set($timezone);
            
            $schedule = new Schedule($this->prefix, $this->plugin_name);
            $schedule->retryToSendToServer();
			
		}
		
		public function deactivation_event(){
			
			$timestamp = wp_next_scheduled(array($this, 'retry_to_send_to_server'));
			wp_unschedule_event($timestamp, array($this, 'retry_to_send_to_server'));
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Setting.php');
			$setting = new setting($this->prefix, $this->plugin_name);
			$setting->activation(BOOKING_PACKAGE_EXTENSION_URL, "deactivation");
			
		}
		
		public function screen_meta($id){
			
			/**
			$screen = get_current_screen();
        	$screen->add_help_tab(array(
				'id'    => 'shortCode',
				'title'   => 'Get Shortcode', 
				'content' => '<p>Use filter for date to reduce output results for appointments. You can filter by <b>location</b>, <b>service</b>, <b>worker</b>, <b>status</b> and <b>date</b>.</p>'
			));
			
			$screen->set_help_sidebar('<a href="https://easy-appointments.net/documentation/">More info!</a>');
			**/
			
		}
		
		public function createFirstCalendar(){
			
			require_once(plugin_dir_path( __FILE__ ).'lib/Schedule.php');
			$schedule = new Schedule($this->prefix, $this->plugin_name);
			$schedule->createFirstCalendar();
			
		}
		
		/**
		public function activation($mode, $id = false){
			
			$id = get_option($this->prefix."activation_id", null);
			$url = BOOKING_PACKAGE_EXTENSION_URL;
			$timezone = get_option('timezone_string');
			$params = array("mode" => $mode, "timeZone" => get_option('timezone_string'), "local" => get_locale(), "site" => get_site_url());
			if(!is_null($id)){
				
				$params['id'] = $id;
				
			}
			#var_dump($params);
			$header = array(
				"Content-Type: application/x-www-form-urlencoded",
				"Content-Length: ".strlen(http_build_query($params))
			);
			
			$context = array(
				"http" => array(
					"method"  => "POST",
					"header"  => implode("\r\n", $header),
					"content" => http_build_query($params)
				)
			);
			
			$response = file_get_contents($url."activation/", false, stream_context_create($context));
			$object = json_decode($response);
			#var_dump($object);
			if($mode == 'activation'){
				
				if(get_option($this->prefix."activation_id") === false){
					
					add_option($this->prefix."activation_id", intval($object->key));
					
				}else{
					
					update_option($this->prefix."activation_id", intval($object->key));
					
				}
				
			}
			
		}
		**/
		
		public function getDictionary($mode, $pluginName){
			
			$dictionary = array(
				'Error' => __('Error', $pluginName),
				'Add' => __('Add', $pluginName),
				'Delete' => __('Delete', $pluginName),
				'Edit' => __('Edit', $pluginName),
				'Change' => __('Change', $pluginName),
				'Return' => __('Return', $pluginName),
				'Save' => __('Save', $pluginName),
				'Done' => __('Done', $pluginName),
				'Cancel' => __('Cancel', $pluginName),
				'Close' => __('Close', $pluginName),
				'Help' => __('Help', $pluginName),
				'Warning' => __('Warning', $pluginName),
				'Booking' => __('Booking', $pluginName),
				'January' => __('January', $pluginName),
				'February' => __('February', $pluginName),
				'March' => __('March', $pluginName),
				'April' => __('April', $pluginName),
				'May' => __('May', $pluginName),
				'June' => __('June', $pluginName),
				'July' => __('July', $pluginName),
				'August' => __('August', $pluginName),
				'September' => __('September', $pluginName),
				'October' => __('October', $pluginName),
				'November' => __('November', $pluginName),
				'December' => __('December', $pluginName),
				'Jan' => __('Jan', $pluginName),
				'Feb' => __('Feb', $pluginName),
				'Mar' => __('Mar', $pluginName),
				'Apr' => __('Apr', $pluginName),
				'May' => __('May', $pluginName),
				'Jun' => __('Jun', $pluginName),
				'Jul' => __('Jul', $pluginName),
				'Aug' => __('Aug', $pluginName),
				'Sep' => __('Sep', $pluginName),
				'Oct' => __('Oct', $pluginName),
				'Nov' => __('Nov', $pluginName),
				'Dec' => __('Dec', $pluginName),
				'Sunday' => __('Sunday', $pluginName),
				'Monday' => __('Monday', $pluginName),
				'Tuesday' => __('Tuesday', $pluginName),
				'Wednesday' => __('Wednesday', $pluginName),
				'Thursday' => __('Thursday', $pluginName),
				'Friday' => __('Friday', $pluginName),
				'Saturday' => __('Saturday', $pluginName),
				'Sun' => __('Sun', $pluginName),
				'Mon' => __('Mon', $pluginName),
				'Tue' => __('Tue', $pluginName),
				'Wed' => __('Wed', $pluginName),
				'Thu' => __('Thu', $pluginName),
				'Fri' => __('Fri', $pluginName),
				'Sat' => __('Sat', $pluginName),
				'Booking Date' => __('Booking Date', $pluginName),
			);
			if($mode == "adomin"){
				
				$dictionary['No reservations'] = __("No reservations", $pluginName);
				$dictionary['No schedules'] = __('No schedules', $pluginName);
				$dictionary['APPROVED'] = __("APPROVED", $pluginName);
				$dictionary['PENDING'] = __('PENDING', $pluginName);
				
				$dictionary['Confirm to send email'] = __('Confirm to send email', $pluginName);
				$dictionary['Send email notification to customer and admin about this operation?'] = __('Send email notification to customer and admin about this operation?', $pluginName);
				$dictionary['Confirm to update'] = __('Confirm to update', $pluginName);
				$dictionary['Update to pending state about this operation?'] = __('Update to pending status about this operation?', $pluginName);
				$dictionary['Update to approval state about this operation?'] = __('Update to approval state about this operation?', $pluginName);
				$dictionary['Refund confirmation'] = __('Refund confirmation', $pluginName);
				$dictionary['This booking has been paid by credit card. Do you refund the price to the customer?'] = __('This booking has been paid by credit card. Do you refund the price to the customer?', $pluginName);
				$dictionary['Confirm to send email'] = __('Confirm to send email', $pluginName);
				$dictionary['Send email notification to customer and admin about this operation?'] = __('Send email notification to customer and admin about this operation?', $pluginName);
				$dictionary['Confirm to delete'] = __('Confirm to delete', $pluginName);
				$dictionary['Do you delete the reservation about this operation?'] = __('Do you delete the reservation about this operation?', $pluginName);
				$dictionary['Please upgrade your free plan to enable this feature.'] = __('Please upgrade your free plan to enable this feature.', $pluginName);
				$dictionary['Service is not registered. '] = __('Service is not registered. ', $pluginName);
				$dictionary['Please create a service on the setting page.'] = __('Please create a service on the setting page.', $pluginName);
				
			}else if($mode == "schedule_page"){
				
				$dictionary['Schedule setting'] = __('Schedule setting', $pluginName);
				$dictionary['Schedule setting on %s'] = __('Schedule setting on %s', $pluginName);
				$dictionary['hour'] = __('hour', $pluginName);
				$dictionary['minutes'] = __('minutes', $pluginName);
				$dictionary['Choose %s'] = __('Choose %s', $pluginName);
				$dictionary['Select booking business'] = __('Select booking business', $pluginName);
				$dictionary['Calendar status'] = __('Calendar status', $pluginName);
				$dictionary['Enable the service function'] = __('Enable the service function', $pluginName);
				$dictionary['Plan name'] = __('Plan name', $pluginName);
				$dictionary['Day (Be completed within your business hours)'] = __('Day (Be completed within your business hours)', $pluginName);
				$dictionary['Accommodation (Hotel)'] = __('Accommodation (Hotel)', $pluginName);
				$dictionary['Publish calendar'] = __('Publish calendar', $pluginName);
				$dictionary['Unpublish calendar'] = __('Unpublish calendar', $pluginName);
				$dictionary['An unknown cause of error occurred'] = __('An unknown cause of error occurred', $pluginName);
				$dictionary['Do you delete the "%s" about this operation?'] = __('Do you delete the "%s" about this operation?', $pluginName);
				$dictionary['Edit schedule'] = __('Edit schedule', $pluginName);
				$dictionary['Return to Calendar list'] = __('Return to Calendar list', $pluginName);
				$dictionary['Add new calendar'] = __('Add new calendar', $pluginName);
				$dictionary['Status'] = __('Status', $pluginName);
				$dictionary['Short Code'] = __('Short Code', $pluginName);
				$dictionary['Name'] = __('Name', $pluginName);
				$dictionary['Active'] = __('Active', $pluginName);
				$dictionary['Price'] = __('Price', $pluginName);
				$dictionary['Duration time'] = __('Duration time', $pluginName);
				$dictionary['Unique ID'] = __('Unique ID', $pluginName);
				$dictionary['Value'] = __('Value', $pluginName);
				$dictionary['Required'] = __('Required', $pluginName);
				$dictionary['Is Name'] = __('Is Name', $pluginName);
				$dictionary['Is a location in Google Calendar'] = __('Is a location in Google Calendar', $pluginName);
				$dictionary['Is Email'] = __('Is Email', $pluginName);
				$dictionary['Type'] = __('Type', $pluginName);
				$dictionary['Options'] = __('Options', $pluginName);
				$dictionary['Add service'] = __('Add service', $pluginName);
				$dictionary['Change ranking'] = __('Change ranking', $pluginName);
				$dictionary['Add filed'] = __('Add filed', $pluginName);
				$dictionary['Do you delete service of "%s"?'] = __('Do you delete service of "%s"?', $pluginName);
				$dictionary['Do you delete filed of "%s"?'] = __('Do you delete filed of "%s"?', $pluginName);
				$dictionary['Disable'] = __('Disable', $pluginName);
				$dictionary['Enable'] = __('Enable', $pluginName);
				$dictionary['New booking'] = __('New booking', $pluginName);
				$dictionary['New booking(Visitor)'] = __('New booking(Visitor)', $pluginName);
				$dictionary['Approval of booking'] = __('Approval of booking', $pluginName);
				$dictionary['Pending of booking'] = __('Pending of booking', $pluginName);
				$dictionary['Cancellation of booking'] = __('Cancellation of booking', $pluginName);
				$dictionary['Delete of booking'] = __('Delete of booking', $pluginName);
				$dictionary['Subject'] = __('Subject', $pluginName);
				$dictionary['Content'] = __('Content', $pluginName);
				$dictionary['Google Calendar ID'] = __('Google Calendar ID', $pluginName);
				
			}else if($mode == "setting_pange"){
				
				$dictionary['Cancel subscription'] = __('Cancel subscription', $pluginName);
				$dictionary['You can use following shortcodes in content editer.'] = __('You can use following shortcodes in content editer.', $pluginName);
				$dictionary['Add filed'] = __('Add filed', $pluginName);
				$dictionary['Change ranking'] = __('Change ranking', $pluginName);
				$dictionary['Add service'] = __('Add service', $pluginName);
				$dictionary['New Course'] = __('New Course', $pluginName);
				$dictionary['New service'] = __('New service', $pluginName);
				$dictionary['Refresh token'] = __('Refresh token', $pluginName);
				$dictionary['Name'] = __('Name', $pluginName);
				$dictionary['Active'] = __('Active', $pluginName);
				$dictionary['Price'] = __('Price', $pluginName);
				$dictionary['Duration time'] = __('Duration time', $pluginName);
				$dictionary['Unique ID'] = __('Unique ID', $pluginName);
				$dictionary['Value'] = __('Value', $pluginName);
				$dictionary['Required'] = __('Required', $pluginName);
				$dictionary['Is Name'] = __('Is Name', $pluginName);
				$dictionary['Is a location in Google Calendar'] = __('Is a location in Google Calendar', $pluginName);
				$dictionary['Is Email'] = __('Is Email', $pluginName);
				$dictionary['Type'] = __('Type', $pluginName);
				$dictionary['Options'] = __('Options', $pluginName);
				$dictionary['New booking(Admin)'] = __('New booking(Admin)', $pluginName);
				$dictionary['Email is sending to Admin after Making of booking.'] = __('Email is sending to Admin after Making of booking.', $pluginName);
				$dictionary['New booking(Visitor)'] = __('New booking(Visitor)', $pluginName);
				$dictionary['Email is sending to visitor after Making of booking.'] = __('Email is sending to visitor after Making of booking.', $pluginName);
				$dictionary['Approval of booking'] = __('Approval of booking', $pluginName);
				$dictionary['Pending of booking'] = __('Pending of booking', $pluginName);
				$dictionary['Booking status is set to Pending'] = __('Booking status is set to Pending', $pluginName);
				$dictionary['Email is sending to Visitor after Booking set as Pending.'] = __('Email is sending to Visitor after Booking set as Pending.', $pluginName);
				$dictionary['Cancellation of booking'] = __('Cancellation of booking', $pluginName);
				$dictionary['Email is sending to Visitor after Deletion of booking.'] = __('Email is sending to Visitor after Deletion of booking.', $pluginName);
				$dictionary['Please upgrade your free plan to enable this feature.'] = __('Please upgrade your free plan to enable this feature.', $pluginName);
				$dictionary['The Service account must be in JSON format.'] = __('The Service account must be in JSON format.', $pluginName);
				
				$dictionary['Subscriptions ID'] = __('Subscriptions ID', $pluginName);
				$dictionary['Invoice ID'] = __('Invoice ID', $pluginName);
				$dictionary['Expiration date'] = __('Expiration date', $pluginName);
				$dictionary['Customers email'] = __('Customers email', $pluginName);
				$dictionary['By using iCal you can share calendars and reservations for Google Calendar, Apple Calendar, iCal format.'] = __('By using iCal you can share calendars and reservations for Google Calendar, Apple Calendar, iCal format.', $pluginName);
				#$dictionary['By using the Google Calendar API you can share information on reserved users with Google Calendar. And you can make and edit new booking from Google Calendar.'] = __('By using the Google Calendar API you can share information on reserved users with Google Calendar. And you can make and edit new booking from Google Calendar.', $pluginName);
				$dictionary['Mailgun is an email automation service. It offers a complete cloud-based email service for sending, receiving and tracking email sent through your websites and applications.'] = __('Mailgun is an email automation service. It offers a complete cloud-based email service for sending, receiving and tracking email sent through your websites and applications.', $pluginName);
				$dictionary['Stripe is the best way to accept payments online and in mobile apps.'] = __('Stripe is the best way to accept payments online and in mobile apps.', $pluginName);
				$dictionary['Do you delete option of "%s"?'] = __('Do you delete option of "%s"?', $pluginName);
				$dictionary['Confirm to cancel'] = __('Confirm to cancel', $pluginName);
				$dictionary['Do you really cancel the subscription?'] = __('Do you really cancel the subscription?', $pluginName);
				$dictionary['Do you delete service of "%s"?'] = __('Do you delete service of "%s"?', $pluginName);
				$dictionary['Do you delete filed of "%s"?'] = __('Do you delete filed of "%s"?', $pluginName);
				$dictionary['General'] = __('General', $pluginName);
				$dictionary['Country'] = __('Country', $pluginName);
				$dictionary['Selected country'] = __('Selected country', $pluginName);
				$dictionary['Frequently used countries'] = __('Frequently used countries', $pluginName);
				$dictionary['Other countries'] = __('Other countries', $pluginName);
				$dictionary['Subject'] = __('Subject', $pluginName);
				$dictionary['Content'] = __('Content', $pluginName);
				
			}else if($mode == "Upgrade_js"){
				
				$dictionary['Credit card'] = __('Credit card', $pluginName);
				$dictionary['Submit Payment'] = __('Submit Payment', $pluginName);
				$dictionary['You have to input missing text fields.'] = __('You have to input missing text fields.', $pluginName);
				$dictionary['Please choose a plan.'] = __('Please choose a plan.', $pluginName);
				$dictionary['First Name'] = __('First Name', $pluginName);
				$dictionary['Last Name'] = __('Last Name', $pluginName);
				$dictionary['Email address'] = __('Email address', $pluginName);
				$dictionary['By taking out a subscription, you agree to %s.'] = __('By taking out a subscription, you agree to %s.', $pluginName);
				$dictionary['the terms of Service'] = __('the terms of Service', $pluginName);
				$dictionary['Thank you for signing up for the subscription.'] = __('Thank you for signing up for the subscription.', $pluginName);
				$dictionary['Please reload this browser.'] = __('Please reload this browser.', $pluginName);
				
			}else if($mode == "display_booking_page"){
				
				$dictionary['Reservation details'] = __('Reservation details', $pluginName);
				$dictionary['Booking now'] = __('Booking now', $pluginName);
				$dictionary['Return to schedules'] = __('Return to schedules', $pluginName);
				$dictionary['Return to calendar'] = __('Return to calendar', $pluginName);
				$dictionary['Reservation Completed'] = __('Reservation Completed', $pluginName);
				$dictionary['Credit card'] = __('Credit card', $pluginName);
				$dictionary['Payment & Booking'] = __('Payment & Booking', $pluginName);
				$dictionary['Service is not registered. '] = __('Service is not registered. ', $pluginName);
				$dictionary['Please create a service on the setting page.'] = __('Please create a service on the setting page.', $pluginName);
				
				
			}
			
			return $dictionary;
			
		}
		
		
	}	
	
	$booking_package = new Booking_app();
	
	
?>